@@ -1,4 +1,4 @@
-# pylint: disable=too-many-branches,too-many-locals
+# pylint: disable=too-many-branches,too-many-locals,too-many-lines
 
 import csv
 import io
@@ -128,7 +128,7 @@ def create_privacy_request(
 
     You cannot update privacy requests after they've been created.
     """
-    if not config.redis.ENABLED:
+    if not config.redis.enabled:
         raise FunctionalityNotConfigured(
             "Application redis cache required, but it is currently disabled! Please update your application configuration to enable integration with a redis cache."
         )
@@ -193,7 +193,16 @@ def create_privacy_request(
                 None,
             )
 
-            if not config.execution.REQUIRE_MANUAL_REQUEST_APPROVAL:
+            if not config.execution.require_manual_request_approval:
+                AuditLog.create(
+                    db=db,
+                    data={
+                        "user_id": "system",
+                        "privacy_request_id": privacy_request.id,
+                        "action": AuditLogAction.approved,
+                        "message": "",
+                    },
+                )
                 queue_privacy_request(privacy_request.id)
 
         except common_exceptions.RedisConnectionError as exc:
@@ -599,7 +608,7 @@ def get_request_preview_queries(
         traversal: Traversal = Traversal(dataset_graph, identity_seed)
         queries: Dict[CollectionAddress, str] = collect_queries(
             traversal,
-            TaskResources(EMPTY_REQUEST, Policy(), connection_configs),
+            TaskResources(EMPTY_REQUEST, Policy(), connection_configs, db),
         )
         return [
             DryRunDatasetResponse(
@@ -936,6 +945,15 @@ def approve_privacy_request(
         privacy_request.reviewed_by = user_id
         privacy_request.save(db=db)
 
+        AuditLog.create(
+            db=db,
+            data={
+                "user_id": user_id,
+                "privacy_request_id": privacy_request.id,
+                "action": AuditLogAction.approved,
+                "message": "",
+            },
+        )
         queue_privacy_request(privacy_request_id=privacy_request.id)
 
     return review_privacy_request(
