@@ -1,10 +1,9 @@
 from typing import Any, Dict
 
+from fideslib.db.base_class import Base
 from sqlalchemy import Column, String
 from sqlalchemy.orm import Session
 
-from fidesops.db.base_class import Base
-
 
 class AuthenticationRequest(Base):
     """
