@@ -30,6 +30,7 @@ from fidesops.common_exceptions import PrivacyRequestPaused
 from fidesops.core.config import config
 from fidesops.db.base_class import JSONTypeOverride
 from fidesops.graph.config import CollectionAddress
+from fidesops.graph.graph_differences import GraphRepr
 from fidesops.models.policy import (
     ActionType,
     PausedStep,
@@ -120,7 +121,7 @@ def generate_request_callback_jwe(webhook: PolicyPreWebhook) -> str:
         scopes=[PRIVACY_REQUEST_CALLBACK_RESUME],
         iat=datetime.now().isoformat(),
     )
-    return generate_jwe(json.dumps(jwe.dict()), config.security.APP_ENCRYPTION_KEY)
+    return generate_jwe(json.dumps(jwe.dict()), config.security.app_encryption_key)
 
 
 class PrivacyRequest(Base):  # pylint: disable=R0904
@@ -437,6 +438,19 @@ class PrivacyRequest(Base):  # pylint: disable=R0904
         )
         return list(value_dict.values())[0] if value_dict else None
 
+    def cache_access_graph(self, value: GraphRepr) -> None:
+        """Cache a representation of the graph built for the access request"""
+        cache: FidesopsRedis = get_cache()
+        cache.set_encoded_object(f"ACCESS_GRAPH__{self.id}", value)
+
+    def get_cached_access_graph(self) -> Optional[GraphRepr]:
+        """Fetch the graph built for the access request"""
+        cache: FidesopsRedis = get_cache()
+        value_dict: Optional[
+            Dict[str, Optional[GraphRepr]]
+        ] = cache.get_encoded_objects_by_prefix(f"ACCESS_GRAPH__{self.id}")
+        return list(value_dict.values())[0] if value_dict else None
+
     def trigger_policy_webhook(self, webhook: WebhookTypes) -> None:
         """Trigger a request to a single customer-defined policy webhook. Raises an exception if webhook response
         should cause privacy request execution to stop.
@@ -575,7 +589,7 @@ class ProvidedIdentity(Base):  # pylint: disable=R0904
         MutableDict.as_mutable(
             StringEncryptedType(
                 JSONTypeOverride,
-                config.security.APP_ENCRYPTION_KEY,
+                config.security.app_encryption_key,
                 AesGcmEngine,
                 "pkcs5",
             )
@@ -590,7 +604,7 @@ class ProvidedIdentity(Base):  # pylint: disable=R0904
         encoding: str = "UTF-8",
     ) -> tuple[str, str]:
         """Utility function to hash a user's password with a generated salt"""
-        SALT = "a-salt"
+        SALT = "$2b$12$UErimNtlsE6qgYf2BrI1Du"
         hashed_value = hash_with_salt(
             value.encode(encoding),
             SALT.encode(encoding),
