@@ -33,7 +33,7 @@ def _valid_data_type(data_type_str: Optional[str]) -> Optional[str]:
     """If the data_type is provided ensure that it is a member of DataType."""
 
     dt, _ = parse_data_type_string(data_type_str)
-    if not is_valid_data_type(dt):
+    if not is_valid_data_type(dt):  # type: ignore
         raise InvalidDataTypeValidationError(
             f"The data type {data_type_str} is not supported."
         )
