@@ -13,7 +13,7 @@ class AesEncryptionRequest(BaseModel):
     @validator("key")
     def validate_key(cls, v: str) -> bytes:
         """Convert string into bytes and verify this is the correct length"""
-        key = v.encode(config.security.ENCODING)
+        key = v.encode(config.security.encoding)
         verify_encryption_key(key)
         return key
 
