@@ -86,8 +86,9 @@ class SaaSRequest(BaseModel):
     Includes optional strategies for postprocessing and pagination.
     """
 
-    path: str
-    method: HTTPMethod
+    request_override: Optional[str]
+    path: Optional[str]
+    method: Optional[HTTPMethod]
     headers: Optional[List[Header]] = []
     query_params: Optional[List[QueryParam]] = []
     body: Optional[str]
@@ -159,6 +160,34 @@ class SaaSRequest(BaseModel):
 
         return values
 
+    @root_validator
+    def validate_override(cls, values: Dict[str, Any]) -> Dict[str, Any]:
+        """Validate that configs related to request overrides are set properly"""
+        if not values.get("request_override"):
+            if not values.get("path"):
+                raise ValueError(
+                    "A request must specify a path if no request_override is provided"
+                )
+            if not values.get("method"):
+                raise ValueError(
+                    "A request must specify a method if no request_override is provided"
+                )
+
+        else:  # if a request override is specified, many fields are NOT allowed
+            invalid = [
+                k
+                for k in values.keys()
+                if values.get(k)
+                and k not in ("request_override", "param_values", "grouped_inputs")
+            ]
+            if invalid:
+                invalid_joined = ", ".join(invalid)
+                raise ValueError(
+                    f"Invalid properties [{invalid_joined}] on a request with request_override specified"
+                )
+
+        return values
+
 
 class Endpoint(BaseModel):
     """A collection of read/update/delete requests which corresponds to a FidesopsDataset collection (by name)"""
@@ -181,6 +210,8 @@ class SaaSType(Enum):
     Enum to store saas connection type in Fidesops
     """
 
+    adobe_campaign = "adobe_campaign"
+    auth0 = "auth0"
     mailchimp = "mailchimp"
     hubspot = "hubspot"
     outreach = "outreach"
@@ -190,9 +221,38 @@ class SaaSType(Enum):
     stripe = "stripe"
     zendesk = "zendesk"
     custom = "custom"
+    sendgrid = "sendgrid"
 
 
-class SaaSConfig(BaseModel):
+class SaaSConfigBase(BaseModel):
+    """
+    Used to store base info for a saas config
+    """
+
+    fides_key: FidesOpsKey
+    name: str
+    type: SaaSType
+
+    @property
+    def fides_key_prop(self) -> FidesOpsKey:
+        return self.fides_key
+
+    @property
+    def name_prop(self) -> str:
+        return self.name
+
+    @validator("type", pre=True)
+    def lowercase_saas_type(cls, value: str) -> str:
+        """Enforce lowercase on saas type."""
+        return value.lower()
+
+    class Config:
+        """Populate models with the raw value of enum fields, rather than the enum itself"""
+
+        use_enum_values = True
+
+
+class SaaSConfig(SaaSConfigBase):
     """
     Used to store endpoint and param configurations for a SaaS connector.
     This is done to separate the details of how to make the API calls
@@ -203,9 +263,6 @@ class SaaSConfig(BaseModel):
     for the graph traversal.
     """
 
-    fides_key: FidesOpsKey
-    name: str
-    type: SaaSType
     description: str
     version: str
     connector_params: List[ConnectorParam]
@@ -214,11 +271,6 @@ class SaaSConfig(BaseModel):
     test_request: SaaSRequest
     data_protection_request: Optional[SaaSRequest] = None  # GDPR Delete
 
-    @validator("type", pre=True)
-    def lowercase_saas_type(cls, value: str) -> str:
-        """Enforce lowercase on saas type."""
-        return value.lower()
-
     @property
     def top_level_endpoint_dict(self) -> Dict[str, Endpoint]:
         """Returns a map of endpoint names mapped to Endpoints"""
@@ -259,16 +311,11 @@ class SaaSConfig(BaseModel):
                 )
 
         return Dataset(
-            name=self.name,
+            name=super().name_prop,
             collections=collections,
-            connection_key=self.fides_key,
+            connection_key=super().fides_key_prop,
         )
 
-    class Config:
-        """Populate models with the raw value of enum fields, rather than the enum itself"""
-
-        use_enum_values = True
-
 
 class SaaSConfigValidationDetails(BaseSchema):
     """
