@@ -111,13 +111,13 @@ class HashMaskingStrategy(MaskingStrategy):
     @staticmethod
     def _hash_sha256(value: str, salt: str) -> str:
         return hashlib.sha256(
-            (value + salt).encode(config.security.ENCODING)
+            (value + salt).encode(config.security.encoding)
         ).hexdigest()
 
     @staticmethod
     def _hash_sha512(value: str, salt: str) -> str:
         return hashlib.sha512(
-            (value + salt).encode(config.security.ENCODING)
+            (value + salt).encode(config.security.encoding)
         ).hexdigest()
 
     @staticmethod
