@@ -1,10 +1,14 @@
+from __future__ import annotations
+
 from abc import ABC, abstractmethod
-from typing import Any, Dict, Optional
+from typing import TYPE_CHECKING, Any, Dict, Optional
 
 from requests import Response
 
 from fidesops.schemas.saas.shared_schemas import SaaSRequestParams
-from fidesops.schemas.saas.strategy_configuration import StrategyConfiguration
+
+if TYPE_CHECKING:
+    from fidesops.schemas.saas.strategy_configuration import StrategyConfiguration
 
 
 class PaginationStrategy(ABC):
