@@ -78,7 +78,7 @@ class FilterPostProcessorStrategy(PostProcessorStrategy):
                     f"strategy: {self.get_strategy_name()}"
                 )
                 return []
-            filter_value = identity_data.get(self.value.identity)
+            filter_value = identity_data.get(self.value.identity)  # type: ignore
 
         try:
             if isinstance(data, list):
@@ -88,7 +88,7 @@ class FilterPostProcessorStrategy(PostProcessorStrategy):
                     if self._matches(
                         self.exact,
                         self.case_sensitive,
-                        filter_value,
+                        filter_value,  # type: ignore
                         pydash.get(item, self.field),
                     )
                 ]
@@ -97,7 +97,7 @@ class FilterPostProcessorStrategy(PostProcessorStrategy):
                 if self._matches(
                     self.exact,
                     self.case_sensitive,
-                    filter_value,
+                    filter_value,  # type: ignore
                     pydash.get(data, self.field),
                 )
                 else []
@@ -160,4 +160,4 @@ class FilterPostProcessorStrategy(PostProcessorStrategy):
 
     @staticmethod
     def get_configuration_model() -> StrategyConfiguration:
-        return FilterPostProcessorConfiguration
+        return FilterPostProcessorConfiguration  # type: ignore
