@@ -8,9 +8,14 @@ from typing import Any, Callable, Dict, List, Optional, Set, Tuple, Union
 
 import dask
 from dask.threaded import get
+from sqlalchemy.orm import Session
 
 from fidesops.common_exceptions import CollectionDisabled, PrivacyRequestPaused
 from fidesops.core.config import config
+from fidesops.graph.analytics_events import (
+    fideslog_graph_rerun,
+    prepare_rerun_graph_analytics_event,
+)
 from fidesops.graph.config import (
     ROOT_COLLECTION_ADDRESS,
     TERMINATOR_ADDRESS,
@@ -20,6 +25,7 @@ from fidesops.graph.config import (
     FieldPath,
 )
 from fidesops.graph.graph import DatasetGraph, Edge, Node
+from fidesops.graph.graph_differences import format_graph_for_caching
 from fidesops.graph.traversal import Traversal, TraversalNode
 from fidesops.models.connectionconfig import AccessLevel, ConnectionConfig
 from fidesops.models.policy import ActionType, Policy
@@ -58,12 +64,12 @@ def retry(
     def decorator(func: Callable) -> Callable:
         @wraps(func)
         def result(*args: Any, **kwargs: Any) -> List[Optional[Row]]:
-            func_delay = config.execution.TASK_RETRY_DELAY
+            func_delay = config.execution.task_retry_delay
             method_name = func.__name__
             self = args[0]
 
             raised_ex: Optional[Union[BaseException, Exception]] = None
-            for attempt in range(config.execution.TASK_RETRY_COUNT + 1):
+            for attempt in range(config.execution.task_retry_count + 1):
                 try:
                     self.skip_if_disabled()
                     # Create ExecutionLog with status in_processing or retrying
@@ -88,7 +94,7 @@ def retry(
                     self.log_skipped(action_type, exc)
                     return default_return
                 except BaseException as ex:  # pylint: disable=W0703
-                    func_delay *= config.execution.TASK_RETRY_BACKOFF
+                    func_delay *= config.execution.task_retry_backoff
                     logger.warning(
                         f"Retrying {method_name} {self.traversal_node.address} in {func_delay} seconds..."
                     )
@@ -568,10 +574,13 @@ def run_access_request(
     graph: DatasetGraph,
     connection_configs: List[ConnectionConfig],
     identity: Dict[str, Any],
+    session: Session,
 ) -> Dict[str, List[Row]]:
     """Run the access request"""
     traversal: Traversal = Traversal(graph, identity)
-    with TaskResources(privacy_request, policy, connection_configs) as resources:
+    with TaskResources(
+        privacy_request, policy, connection_configs, session
+    ) as resources:
 
         def collect_tasks_fn(
             tn: TraversalNode, data: Dict[CollectionAddress, GraphTask]
@@ -599,6 +608,13 @@ def run_access_request(
         dsk[TERMINATOR_ADDRESS] = (termination_fn, *end_nodes)
         update_mapping_from_cache(dsk, resources, start_function)
 
+        fideslog_graph_rerun(
+            prepare_rerun_graph_analytics_event(
+                privacy_request, env, end_nodes, resources, ActionType.access
+            )
+        )
+        privacy_request.cache_access_graph(format_graph_for_caching(env, end_nodes))
+
         v = dask.delayed(get(dsk, TERMINATOR_ADDRESS, num_workers=1))
         return v.compute()
 
@@ -636,17 +652,20 @@ def update_erasure_mapping_from_cache(
         )
 
 
-def run_erasure(  # pylint: disable = too-many-arguments
+def run_erasure(  # pylint: disable = too-many-arguments, too-many-locals
     privacy_request: PrivacyRequest,
     policy: Policy,
     graph: DatasetGraph,
     connection_configs: List[ConnectionConfig],
     identity: Dict[str, Any],
     access_request_data: Dict[str, List[Row]],
+    session: Session,
 ) -> Dict[str, int]:
     """Run an erasure request"""
     traversal: Traversal = Traversal(graph, identity)
-    with TaskResources(privacy_request, policy, connection_configs) as resources:
+    with TaskResources(
+        privacy_request, policy, connection_configs, session
+    ) as resources:
 
         def collect_tasks_fn(
             tn: TraversalNode, data: Dict[CollectionAddress, GraphTask]
@@ -656,7 +675,7 @@ def run_erasure(  # pylint: disable = too-many-arguments
                 data[tn.address] = GraphTask(tn, resources)
 
         env: Dict[CollectionAddress, Any] = {}
-        traversal.traverse(env, collect_tasks_fn)
+        end_nodes = traversal.traverse(env, collect_tasks_fn)
 
         def termination_fn(*dependent_values: int) -> Tuple[int, ...]:
             """The dependent_values here is an int output from each task feeding in, where
@@ -672,6 +691,11 @@ def run_erasure(  # pylint: disable = too-many-arguments
         # terminator function waits for all keys
         dsk[TERMINATOR_ADDRESS] = (termination_fn, *env.keys())
         update_erasure_mapping_from_cache(dsk, resources, start_function)
+        fideslog_graph_rerun(
+            prepare_rerun_graph_analytics_event(
+                privacy_request, env, end_nodes, resources, ActionType.erasure
+            )
+        )
         v = dask.delayed(get(dsk, TERMINATOR_ADDRESS, num_workers=1))
 
         update_cts: Tuple[int, ...] = v.compute()
